import unittest

from ..tests.test_sitemaps import *

__title__ = 'qartez.tests'
__author__ = 'Artur Barseghyan'
__copyright__ = 'Copyright (c) 2013-2014 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'


if __name__ == '__main__':
    unittest.main()
